@@ -1,4 +1,4 @@
-from userverse_python_client.client_error import AppClientError
+from userverse_python_client.error_model import ClientErrorModel
 from sverse_generic_models.app_error import AppErrorResponseModel, DetailModel
 
 
@@ -6,7 +6,7 @@ def test_app_client_error_includes_detail_error():
     payload = AppErrorResponseModel(
         detail=DetailModel(message="Bad request", error="missing")
     )
-    err = AppClientError(status_code=400, payload=payload)
+    err = ClientErrorModel(status_code=400, payload=payload)
     assert err.status_code == 400
     assert err.payload == payload
     assert "Bad request" in str(err)
@@ -17,5 +17,5 @@ def test_app_client_error_without_detail_error():
     payload = AppErrorResponseModel(
         detail=DetailModel(message="Bad request", error=None)
     )
-    err = AppClientError(status_code=400, payload=payload)
+    err = ClientErrorModel(status_code=400, payload=payload)
     assert "Bad request" == str(err)
